==> mobx-forms-0.0.2.tgz: package/lib/utils/__tests__/prepareProps.spec.js <==
'use strict';

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _prepareProps = require('../prepareProps');

var _prepareProps2 = _interopRequireDefault(_prepareProps);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

jest.unmock('../prepareProps');
jest.unmock('../consts');
jest.unmock('ramda');

var onChange = function onChange(id) {
  return id;
};
var onFocus = function onFocus(id) {
  return id;
};
var onBlur = function onBlur(id) {
  return id;
};

var props = {
  // input
  // ---
  value: 1337,
  required: true,
  onChange: onChange,
  onFocus: onFocus,
  onBlur: onBlur,

  // meta
  // ---
  error: 'not enough peanuts',
  valid: false,
  dirty: false,
  pristine: true,
  touched: true,
  active: false,

  // custom
  // ---
  damage: 'tons of',
  wow: 'so test'
};

var props2 = _extends({}, props, {
  value: true
});

describe('#prepareProps', function () {
  it('should separate input props', function () {
    var result = (0, _prepareProps2.default)(props);
    expect(result.input.value).toBe(1337);
    expect(result.input.required).toBe(true);
    expect(result.input.onChange).toBeDefined();
    expect(result.input.onFocus).toBeDefined();
    expect(result.input.onBlur).toBeDefined();
  });

  it('should separate meta props', function () {
    var result = (0, _prepareProps2.default)(props);
    expect(result.meta.error).toBe('not enough peanuts');
    expect(result.meta.valid).toBe(false);
    expect(result.meta.dirty).toBe(false);
    expect(result.meta.pristine).toBe(true);
    expect(result.meta.touched).toBe(true);
    expect(result.meta.active).toBe(false);
  });

  it('should separate custom props', function () {
    var result = (0, _prepareProps2.default)(props);
    expect(result.custom.damage).toBe('tons of');
    expect(result.custom.wow).toBe('so test');
  });

  it('should add a "checked" prop for boolean value', function () {
    var result = (0, _prepareProps2.default)(props2);
    expect(result.input.checked).toBe(true);
  });
});

==> mobx-forms-0.1.1.tgz: package/lib/utils/__tests__/prepareProps.spec.js <==
'use strict';

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _prepareProps = require('../prepareProps');

var _prepareProps2 = _interopRequireDefault(_prepareProps);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var onChange = function onChange(id) {
  return id;
};
var onFocus = function onFocus(id) {
  return id;
};
var onBlur = function onBlur(id) {
  return id;
};

var props = {
  // input
  // ---
  value: 1337,
  required: true,
  onChange: onChange,
  onFocus: onFocus,
  onBlur: onBlur,

  // meta
  // ---
  error: 'not enough peanuts',
  dirty: false,
  visited: false,
  touched: true,
  active: false,

  // custom
  // ---
  damage: 'tons of',
  wow: 'so test'
};

var props2 = _extends({}, props, {
  value: true
});

describe('#prepareProps', function () {
  it('should separate input props', function () {
    var result = (0, _prepareProps2.default)(props);
    expect(result.input.value).toBe(1337);
    expect(result.input.required).toBe(true);
    expect(result.input.onChange).toBeDefined();
    expect(result.input.onFocus).toBeDefined();
    expect(result.input.onBlur).toBeDefined();
  });

  it('should separate meta props', function () {
    var result = (0, _prepareProps2.default)(props);
    expect(result.meta.error).toBe('not enough peanuts');
    expect(result.meta.dirty).toBe(false);
    expect(result.meta.visited).toBe(false);
    expect(result.meta.touched).toBe(true);
    expect(result.meta.active).toBe(false);
  });

  it('should separate custom props', function () {
    var result = (0, _prepareProps2.default)(props);
    expect(result.custom.damage).toBe('tons of');
    expect(result.custom.wow).toBe('so test');
  });

  it('should add a "checked" prop for boolean value', function () {
    var result = (0, _prepareProps2.default)(props2);
    expect(result.input.checked).toBe(true);
  });
});
